import { Component } from '@angular/core';
import { NavController, AlertController, ToastController } from 'ionic-angular';
import { DefaultListable } from '../../defaults/default-listable';
import { INavigable } from '../../interfaces/navigable-interface';
import { Product } from '../../models/product';
import { ProductDetailsPage } from '../product-details/product-details';
import { DataProvider } from '../../providers/data-provider'

@Component({
    selector: 'page-product-list',
    providers: [DataProvider],
    templateUrl: 'product-list.html'
})
export class ProductListPage extends DefaultListable<Product> implements INavigable {

    constructor(
        public navCtrl: NavController,
        public data: DataProvider,
        public alertCtrl: AlertController,
        public toastCtrl: ToastController
    ){
        super();
        this.initialize();
    }

    /**
     * Initialize data list
     */
    initialize(): void {
        this.data.getAll("product").then(r => { 
            this.elements = r.products;
        });
    }

    /**
     * Goto page
     */
    goToPage(page: any) {
        this.navCtrl.push(ProductDetailsPage, this.elements);
    }

    /**
     *
     */
    openItem(index: number) {
        this.navCtrl.push(ProductDetailsPage, this.elements[index]);
    }

    /**
     *
     */
    removeItem() {
        this.alertCtrl.create({
            title: "Confirmar",
            message: "Desea borrar este producto?",
            buttons: [
                {
                    text: "Cancelar",
                    handler: () => {
                        this.toggleDelete(-1);
                    }
                },
                {
                    text: "Aceptar",
                    handler: () => {
                        let item = this.elements[this.selectedIndex];
                        this.toggleDelete(-1);

                        this.data.delete("product", item).then(result => {
                            this.elements.splice(this.selectedIndex, 1);

                            this.toastCtrl.create({
                                message: "Producto eliminado",
                                duration: 500
                            }).present();
                        }).catch(() => {
                            this.toastCtrl.create({
                                message: "No se pudo eliminar el producto",
                                duration: 500
                            }).present();
                        });
                    }
                }
            ]
        }).present();
    }
}
